{% extends "base.html" %}
{% load static %}
{% block content %}
    {% include "messages.html" %}
    <div class="bg-gray-50 flex flex-col py-12 sm:px-6 lg:px-8">
        <div class="sm:mx-auto sm:w-full sm:max-w-md">
            <img class="mx-auto h-12 w-auto" src="https://tailwindui.com/img/logos/workflow-mark-pc-600.svg"
                 alt="Workflow">
            <h2 class="mt-6 text-center text-3xl font-extrabold text-gray-900">
                Forgot Password
            </h2>
        </div>

        <div class="mt-8 sm:mx-auto sm:w-full sm:max-w-md">
            <div class="bg-white py-8 px-4 shadow sm:rounded-lg sm:px-10">
                todo: wir haben vielleicht eine email geschickt
            </div>
        </div>
    </div>
{% endblock %}