{% extends "base.html" %}
{% load static crispy_forms_tags %}
{% block content %}
{% if validlink %}
    {% include "messages.html" %}
    <div class="bg-gray-50 flex flex-col py-12 sm:px-6 lg:px-8">
        <div class="sm:mx-auto sm:w-full sm:max-w-md">
            <img class="mx-auto h-12 w-auto" src="https://tailwindui.com/img/logos/workflow-mark-pc-600.svg"
                 alt="Workflow">
            <h2 class="mt-6 text-center text-3xl font-extrabold text-gray-900">
                Set New Password
            </h2>
        </div>

        <div class="mt-8 sm:mx-auto sm:w-full sm:max-w-md">
            <div class="bg-white py-8 px-4 shadow sm:rounded-lg sm:px-10">
                {% crispy form form.helper %}
            </div>
        </div>
    </div>
{% else %}
<p>The password reset link was invalid, possibly because it has already been used.  Please request a new password reset.</p>
{% endif %}
{% endblock%}
