<div class="flex-1 flex flex-col overflow-y-auto bg-gray-800">
    <nav class="flex-1 px-2 py-4">
        {% for cat_key, cat in menu.main.items %}
        <div class="space-y-1 pb-4">
            {% for link_key, link in cat.items %}
                {% include "dashboard/menu-entry.html" with url_name=link.0 url_title=link.1 icon_name=link.2 %}
            {% endfor %}
        </div>
        {% endfor %}
        {% if 'links' in menu %}
        <div class="mt-10">
            <p class="px-3 text-xs font-semibold text-gray-400 uppercase tracking-wider">
                Links
            </p>
            <div class="mt-2 space-y-1">
            {% for link_key, link in menu.links.items %}
                <a href="{{ link.0 }}"
                   class="group flex items-center px-3 py-2 text-sm font-medium text-gray-300 rounded-md hover:text-white hover:bg-gray-700">
                <span class="truncate">
                  {{ link.1 }}
                </span>
                </a>
            {% endfor %}
            </div>
        </div>
        {% endif %}
    </nav>
</div>