{% extends "dashboard/base.html" %}
{% load static crispy_forms_tags %}
{% block content %}
    <form action="#" method="POST">
        <div class="shadow sm:rounded-md sm:overflow-hidden bg-white">
            <div class="px-4 py-5 border-b border-gray-200 sm:px-6">
                <h3 class="text-lg leading-6 font-medium text-gray-900">
                    Your Account
                </h3>
            </div>
            <div class="bg-white py-8 px-4 shadow sm:rounded-lg sm:px-10 space-y-6">
                {% crispy form form.helper %}
            </div>
        </div>
    </form>
{% endblock %}
